==> odoo_addon_l10n_it_account_stamp-16.0.1.1.0-py3-none-any.whl: odoo/addons/l10n_it_account_stamp/readme/CONFIGURE.md <==
**Italiano**

Per modificare le impostazioni sul prodotto "Imposta di bollo 2 euro" è
necessario abilitare le funzioni complete per la contabilità:

1.  Impostazioni -\> Utenti e aziende -\> Gruppi
2.  Cercare il gruppo "Mostrare funzionalità contabili complete" e
    selezionarlo
3.  Nel tab "Utenti" aggiungere l'utente e salvare

Modalità automatica:

- andare sul prodotto "Imposta di bollo 2 euro" e configurare "Imposte
  marca da bollo" (Imposte in esenzione).
- per ciascuna fattura o ricevuta, l'applicabilità dell'imposta di bollo
  verrà calcolata in modo automatico in base alla somma degli imponibili
  relativi alle imposte selezionate.

Modalità manuale:

- andare sul prodotto "Imposta di bollo 2 euro" e deselezionare la
  casella "Calcolo automatico".
- per ciascuna fattura o ricevuta, abilitare manualmente la casella di
  selezione "Imposta di bollo". L'applicabilità dell'imposta di bollo
  verrà calcolata in base alla somma degli imponibili relativi alle
  imposte selezionate.

Impostare i conti di ricavo/costo nella scheda "Contabilità",
generalmente ricavo="Debiti per bolli" e costo="Valori bollati".

**English**

In order to change Tax Stamp 2 euro product settings, enable full
accounting features:

1.  Settings -\> Users & Companies -\> Groups
2.  Search "Show Full Accounting Features" group and select it
3.  In "Users" Tab, add user and save

Automatic mode:

- Go to 'Tax Stamp 2 euro' product and configure 'Stamp taxes'
  (exemption taxes).
- For each invoice or receipt, the base amount for each selected tax
  will be added up and used to determine the application of the account
  stamp.

Manual mode:

- Go to 'Tax Stamp 2 euro' product and deselect 'Auto-compute' checkbox.
- For each invoice or receipt, manually enable 'Tax Stamp' checkbox.

Also set income/expense accounts, typically income = 'Debiti per bolli'
and expense = 'Valori bollati'.

==> odoo_addon_l10n_it_account_stamp-18.0.1.1.1-py3-none-any.whl: odoo/addons/l10n_it_account_stamp/readme/CONFIGURE.md <==
**Italiano**

Per modificare le impostazioni sul prodotto "Imposta di bollo 2 euro" è
necessario abilitare le funzioni complete per la contabilità:

1.  Impostazioni -\> Utenti e aziende -\> Gruppi
2.  Cercare il gruppo "Mostrare funzionalità contabili complete" e
    selezionarlo
3.  Nel tab "Utenti" aggiungere l'utente e salvare

Modalità automatica:

- andare sul prodotto "Imposta di bollo 2 euro" e configurare "Imposte
  per bollo" (Imposte in esenzione).
- per ciascuna fattura o ricevuta, l'applicabilità dell'imposta di bollo
  verrà calcolata in modo automatico in base alla somma degli imponibili
  relativi alle imposte selezionate.

Modalità manuale:

- andare sul prodotto "Imposta di bollo 2 euro" e deselezionare la
  casella "Calcolo automatico".
- per ciascuna fattura o ricevuta, abilitare manualmente la casella di
  selezione "Imposta di bollo". L'applicabilità dell'imposta di bollo
  verrà calcolata in base alla somma degli imponibili relativi alle
  imposte selezionate.

Impostare i conti di ricavo/costo nella scheda "Contabilità",
generalmente ricavo="Debiti per bolli" e costo="Valori bollati".

**English**

In order to change 'Stamp duty 2 euro' product settings, enable full
accounting features:

1.  Settings -\> Users & Companies -\> Groups
2.  Search "Show Full Accounting Features" group and select it
3.  In "Users" Tab, add user and save

Automatic mode:

- Go to 'Stamp duty 2 euro' product and configure 'Stamp taxes'
  (exemption taxes).
- For each invoice or receipt, the base amount for each selected tax
  will be added up and used to determine the application of the account
  stamp.

Manual mode:

- Go to 'Stamp duty 2 euro' product and deselect 'Auto-compute' checkbox.
- For each invoice or receipt, manually enable 'Stamp Duty' checkbox.

Also set income/expense accounts, typically income = 'Debiti per bolli'
and expense = 'Valori bollati'.
